pub struct Uniform<X>(/* private fields */)
where
X: SampleUniform;Expand description
Sample values uniformly between two bounds.
Uniform::new and Uniform::new_inclusive construct a uniform
distribution sampling from the given range; these functions may do extra
work up front to make sampling of multiple values faster. If only one sample
from the range is required, Rng::gen_range can be more efficient.
When sampling from a constant range, many calculations can happen at
compile-time and all methods should be fast; for floating-point ranges and
the full range of integer types this should have comparable performance to
the Standard distribution.
Steps are taken to avoid bias which might be present in naive
implementations; for example rng.gen::<u8>() % 170 samples from the range
[0, 169] but is twice as likely to select numbers less than 85 than other
values. Further, the implementations here give more weight to the high-bits
generated by the RNG than the low bits, since with some RNGs the low-bits
are of lower quality than the high bits.
Implementations must sample in [low, high) range for
Uniform::new(low, high), i.e., excluding high. In particular, care must
be taken to ensure that rounding never results values < low or >= high.
Example
use rand::distributions::{Distribution, Uniform};
let between = Uniform::from(10..10000);
let mut rng = rand::thread_rng();
let mut sum = 0;
for _ in 0..1000 {
sum += between.sample(&mut rng);
}
println!("{}", sum);For a single sample, Rng::gen_range may be preferred:
use rand::Rng;
let mut rng = rand::thread_rng();
println!("{}", rng.gen_range(0..10));Implementations
Sourceimpl<X> Uniform<X>where
X: SampleUniform,
impl<X> Uniform<X>where
X: SampleUniform,
Sourcepub fn new<B1, B2>(low: B1, high: B2) -> Uniform<X>where
B1: SampleBorrow<X>,
B2: SampleBorrow<X>,
pub fn new<B1, B2>(low: B1, high: B2) -> Uniform<X>where
B1: SampleBorrow<X>,
B2: SampleBorrow<X>,
Create a new Uniform instance which samples uniformly from the half
open range [low, high) (excluding high). Panics if low >= high.
Sourcepub fn new_inclusive<B1, B2>(low: B1, high: B2) -> Uniform<X>where
B1: SampleBorrow<X>,
B2: SampleBorrow<X>,
pub fn new_inclusive<B1, B2>(low: B1, high: B2) -> Uniform<X>where
B1: SampleBorrow<X>,
B2: SampleBorrow<X>,
Create a new Uniform instance which samples uniformly from the closed
range [low, high] (inclusive). Panics if low > high.